@@ -1,11 +1,12 @@
 package Dist::Zilla::Plugin::PodWeaver;
-our $VERSION = '3.100710';
+BEGIN {
+  $Dist::Zilla::Plugin::PodWeaver::VERSION = '3.101530';
+}
 # ABSTRACT: weave your Pod together from configuration and Dist::Zilla
 use Moose;
 use Moose::Autobox;
 use List::MoreUtils qw(any);
 use Pod::Weaver 3.100710; # logging with proxies
-use Dist::Zilla::Role::FileMunger 1.100710; # logging with proxies
 with 'Dist::Zilla::Role::FileMunger';
 
 use namespace::autoclean;
@@ -21,9 +22,12 @@ use Pod::Weaver::Config::Assembler;
 sub weaver {
   my ($self) = @_;
 
-  my @files = glob('weaver.*');
+  my @files = glob($self->zilla->root->file('weaver.*'));
 
-  my $arg = { root_config => { logger => $self->logger } };
+  my $arg = {
+      root        => $self->zilla->root,
+      root_config => { logger => $self->logger },
+  };
 
   if ($self->config_plugin) {
     my $assembler = Pod::Weaver::Config::Assembler->new;
@@ -111,7 +115,7 @@ Dist::Zilla::Plugin::PodWeaver - weave your Pod together from configuration and
 
 =head1 VERSION
 
-version 3.100710
+version 3.101530
 
 =head1 DESCRIPTION
 
